@@ -13,7 +13,7 @@ from mcdbot.mcdbot import Mcdbot
 async def start(main: Mcdbot, msg, context):
     dm_channel = msg.author.dm_channel
     if dm_channel is None:
-        dm_channel = await msg.author.crete_dm()
+        dm_channel = await msg.author.create_dm()
 
     await dm_channel.send("Hello! Type !mc help for help.")
     return None
