@@ -8,5 +8,5 @@
 #  =========
 
 
-async def unavailiable_in_context(main, msg, *args):
+async def unavailiable_in_context(main, msg, context, *args):
     return "[ERROR] The command you used isn't usable in this context!"
